netapp_ontap.models.metrocluster_remote API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.metrocluster_remote`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class MetroclusterRemoteSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the MetroclusterRemote object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `automatic_uso_failure_domain: str GET POST PATCH`

    This parameter specifies the configuration of automatic switchover. The valid values for the parameter are ':' cluster':' triggers an unplanned switchover if all nodes in a DR cluster are down. dr_group':' triggers an unplanned switchover if both nodes of a DR group are down. disabled':' automatic switchover is disabled. If the cluster is not reachable due to errors, the parameter value will be set to not_reachable. This value is read only. If the cluster configuration is unknown, the parameter value will be set to unknown and the value is read only.

    Valid choices:

    - dr_group
    - cluster
    - disabled
    - not_reachable
    - unknown
  `cluster: Cluster GET POST PATCH`

    The cluster field of the metrocluster_remote.

  `configuration_state: str GET`

    Indicates the state of the remote cluster configuration.

    Valid choices:

    - configuration_error
    - configured
    - not_configured
    - not_reachable
    - partially_configured
    - unknown
  `mode: str GET`

    Specifies the mode of operation of the remote cluster.

    Valid choices:

    - normal
    - not_configured
    - not_reachable
    - partial_switchback
    - partial_switchover
    - switchover
    - unknown
    - waiting_for_switchback
  `periodic_check_enabled: bool GET`

    Indicates whether or not a periodic check is enabled on the remote cluster.